@@ -42,6 +42,7 @@ class Worker:
         before_process=None,
         after_process=None,
         timers=None,
+        dequeue_timeout=0,
     ):
         self.queue = queue
         self.concurrency = concurrency
@@ -60,6 +61,7 @@ class Worker:
         self.functions = {}
         self.context = {"worker": self}
         self.tasks = set()
+        self.dequeue_timeout = dequeue_timeout
 
         for function in functions:
             if isinstance(function, tuple):
@@ -140,11 +142,16 @@ class Worker:
                 await job.update()
 
     async def process(self):
+        # pylint: disable=too-many-branches
         job = None
         monitor = None
 
         try:
-            job = await self.queue.dequeue()
+            job = await self.queue.dequeue(self.dequeue_timeout)
+            if not job:
+                # Dequeue timed out so return early
+                return
+
             job_id = job.id
             job.started = now()
             job.status = Status.ACTIVE
@@ -179,6 +186,10 @@ class Worker:
                 else:
                     await job.retry(error)
         finally:
+            if monitor and not monitor.done():
+                monitor.cancel()
+                await asyncio.gather(monitor, return_exceptions=True)
+
             if (
                 self.after_process
                 and job
@@ -186,10 +197,6 @@ class Worker:
             ):
                 await self.after_process(context)
 
-            if monitor and not monitor.done():
-                monitor.cancel()
-                await asyncio.gather(monitor, return_exceptions=True)
-
     def _process(self, previous_task=None):
         if previous_task:
             self.tasks.discard(previous_task)
@@ -200,13 +207,17 @@ class Worker:
             new_task.add_done_callback(self._process)
 
 
-def start(settings, web=False, port=8080):
+def import_settings(settings):
     import importlib
 
-    # given a.b.c, parses out a.b as the  module path and c as the variable
+    # given a.b.c, parses out a.b as the module path and c as the variable
     module_path, name = settings.strip().rsplit(".", 1)
     module = importlib.import_module(module_path)
-    settings = getattr(module, name)
+    return getattr(module, name)
+
+
+def start(settings, web=False, port=8080):
+    settings = import_settings(settings)
 
     if "queue" not in settings:
         settings["queue"] = Queue.from_url("redis://localhost")
@@ -228,3 +239,22 @@ def start(settings, web=False, port=8080):
         aiohttp.web.run_app(app, port=port, loop=loop)
     else:
         loop.run_until_complete(worker.start())
+
+
+async def async_check_health(queue: Queue) -> int:
+    info = await queue.info()
+    if not info.get(queue.name):
+        logger.warning("Health check failed")
+        status = 1
+    else:
+        logger.info(info[queue.name])
+        status = 0
+    await queue.disconnect()
+    return status
+
+
+def check_health(settings: str) -> int:
+    settings = import_settings(settings)
+    loop = asyncio.new_event_loop()
+    queue = settings.get("queue", Queue.from_url("redis://localhost"))
+    return loop.run_until_complete(async_check_health(queue))
